@@ -79,10 +79,13 @@ def encode(d, opt={}):
             '_ArrayData_': [d.real, d.imag]
           };
         return newobj;
-    elif isinstance(d, np.ndarray):
+    elif type(d).__module__ == np.__name__:
         newobj={};
         newobj["_ArrayType_"]=jdtype[str(d.dtype)] if (str(d.dtype) in jdtype) else str(d.dtype);
-        newobj["_ArraySize_"]=list(d.shape);
+        if(np.isscalar(d)):
+            newobj["_ArraySize_"]=[1];
+        else:
+            newobj["_ArraySize_"]=list(d.shape);
         if(d.dtype==np.complex64 or d.dtype==np.complex128 or d.dtype==np.csingle or d.dtype==np.cdouble):
                 newobj['_ArrayIsComplex_']=True;
                 newobj['_ArrayData_']=[list(d.flatten().real), list(d.flatten().imag)];
@@ -162,14 +165,12 @@ def decode(d, opt={}):
                     newobj=zlib.decompress(bytes(newobj),zlib.MAX_WBITS|32)
                 elif(d['_ArrayZipType_']=='lzma'):
                     try:
-                        try:
-                            import lzma
-                        except ImportError:
-                            from backports import lzma
-                        newobj=lzma.decompress(bytes(newobj),lzma.FORMAT_ALONE)
-                    except Exception:
-                        print('you must install "lzma" module to decompress a data record in this file, ignoring')
-                        pass
+                        import lzma
+                    except ImportError:
+                        from backports import lzma
+                    buf=bytearray(newobj)  # set length to -1 (unknown) if EOF appears
+                    buf[5:13] = b'\xff\xff\xff\xff\xff\xff\xff\xff'
+                    newobj=lzma.decompress(buf,lzma.FORMAT_ALONE)
                 elif(d['_ArrayZipType_']=='lz4'):
                     try:
                         import lz4.frame
@@ -177,7 +178,6 @@ def decode(d, opt={}):
                     except Exception:
                         print('Warning: you must install "lz4" module to decompress a data record in this file, ignoring')
                         pass
-
                 newobj=np.fromstring(newobj,dtype=np.dtype(d['_ArrayType_'])).reshape(d['_ArrayZipSize_']);
                 if('_ArrayIsComplex_' in d and newobj.shape[0]==2):
                     newobj=newobj[0]+1j*newobj[1];
@@ -185,6 +185,8 @@ def decode(d, opt={}):
                     newobj=newobj.reshape(d['_ArraySize_'],order='F')
                 else:
                     newobj=newobj.reshape(d['_ArraySize_'])
+                if(len(d['_ArraySize_']) == 1 and d['_ArraySize_'][0] == 1):
+                    newobj=np.asscalar(newobj);
                 return newobj;
             elif('_ArrayData_' in d):
                 if(isinstance(d['_ArrayData_'],str)):
@@ -201,6 +203,8 @@ def decode(d, opt={}):
                     newobj=newobj.reshape(d['_ArraySize_'],order='F')
                 else:
                     newobj=newobj.reshape(d['_ArraySize_'])
+                if(len(d['_ArraySize_']) == 1 and d['_ArraySize_'][0] == 1):
+                    newobj=np.asscalar(newobj);
                 return newobj;
             else:
                 raise Exception('JData', 'one and only one of _ArrayData_ or _ArrayZipData_ is required')
